<?php
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\admin\AdminController;
use App\Http\Controllers\admin\AppointmentsController;
use App\Http\Controllers\admin\UserController;
use App\Http\Controllers\admin\PlansController;
use App\Http\Controllers\admin\SettingsController;
use App\Http\Controllers\admin\PaymentController;
use App\Http\Controllers\admin\BusinessController;
use App\Http\Controllers\admin\InquiryController;
use App\Http\Controllers\web\HomeController;
use App\Http\Controllers\admin\SystemAddonsController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Mail;

/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web Routes for your application. These
| Routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/
Route::group(['prefix' => 'admin', 'namespace' => 'admin'], function () {
    // Auth
    Route::get('/', [UserController::class, 'login']);
    Route::post('logout', [UserController::class, 'logout']);
    //Route::get('register', [UserController::class, 'userregister']);
    Route::post('systemverification', [UserController::class, 'systemverification']);
    Route::get('otp-verification', [UserController::class, 'otpverification']);
    Route::get('resendotp', [UserController::class, 'resendotp']);
    Route::get('forgotpassword', [UserController::class, 'forgotpassword']);
    Route::get('logout', [UserController::class, 'logout']);
    Route::post('checklogin', [UserController::class, 'checklogin']);
    Route::post('store', [UserController::class, 'register']);
    Route::post('otpverify', [UserController::class, 'otpverify']);
    Route::post('sendpassword', [UserController::class, 'sendpassword']);
    Route::group(['middleware' => 'Authenticate'], function () {
        // Dashboard
        Route::get('dashboard', [AdminController::class, 'index']);
        Route::get('admin_login', [UserController::class, 'admin_login']);
        // Users
        Route::prefix('users')->group(function () {
            Route::middleware(['middleware' => 'admin'])->group(function () {
                Route::get('/', [UserController::class, 'index'])->name('users');
                Route::get('add', [UserController::class, 'addusers']);
                Route::post('store', [UserController::class, 'storeuser']);
                Route::get('edit-{id}', [UserController::class, 'getuser']);
                Route::post('changestatus', [UserController::class, 'changestatus']);
                Route::post('deleteuser', [UserController::class, 'deleteuser']);
                Route::get('resetpassword-{id}', [UserController::class, 'resetpassword']);
                Route::post('reset-{id}', [UserController::class, 'reset']);
                Route::get('vendor_login-{id}', [UserController::class, 'vendor_login']);
            });
            Route::post('update-{id}', [UserController::class, 'updateuser']);
            Route::post('changepassword', [UserController::class, 'changepassword']);
        });
        // Settings
        Route::get('settings', [SettingsController::class, 'index']);
        Route::post('basicinfo/store', [SettingsController::class, 'store']);
        // Pricing Plan
        Route::prefix('plans')->group(function () {
            Route::get('/', [PlansController::class, 'index']);
            Route::get('selectplan-{id}', [PlansController::class, 'selectplan'])->middleware('vendor');
            Route::post('buyplan', [PlansController::class, 'buyplan'])->middleware('vendor');
            Route::group(['middleware' => 'admin'], function () {
                Route::post('changestatus', [PlansController::class, 'changestatus']);
                Route::get('add', [PlansController::class, 'addplans'])->middleware('admin');
                Route::post('store', [PlansController::class, 'store']);
                Route::get('edit-{id}', [PlansController::class, 'getplan']);
                Route::post('update-{id}', [PlansController::class, 'updateplan']);
            });
        });
        // Payments
        Route::get('payments', [PaymentController::class, 'index'])->middleware('admin');
        Route::post('paymentmethod', [PaymentController::class, 'paymentmethod'])->middleware('admin');
        // Transaction
        Route::get('transaction', [PaymentController::class, 'transaction']);
        // Business
        Route::group(['prefix' => 'business'], function () {
            Route::group(['middleware' => 'vendor'], function () {
                Route::get('/', [BusinessController::class, 'index']);
                Route::post('business_add', [BusinessController::class, 'business_add']);
                Route::get('business_edit-{id}', [BusinessController::class, 'business_edit']);
                Route::post('business_delete', [BusinessController::class, 'business_delete']);
                Route::post('store_basic_info-{id}', [BusinessController::class, 'store_basic_info']);
                Route::post('store_contact_info-{id}', [BusinessController::class, 'store_contact_info']);
                Route::get('delete_contact_field-{id}', [BusinessController::class, 'delete_contact_field']);
                Route::post('store_business_hours', [BusinessController::class, 'store_business_hours']);
                Route::post('store_appointments_slot-{id}', [BusinessController::class, 'store_appointments_slot']);
                Route::get('delete_appointments_slot-{id}', [BusinessController::class, 'delete_appointments_slot']);
                Route::post('store_services-{id}', [BusinessController::class, 'store_services']);
                Route::get('delete_services-{id}', [BusinessController::class, 'delete_services']);
                Route::post('store_promotional_videos-{id}', [BusinessController::class, 'store_promotional_videos']);
                Route::get('delete_promotional_videos-{id}', [BusinessController::class, 'delete_promotional_videos']);
                Route::post('store_testimonials-{id}', [BusinessController::class, 'store_testimonials']);
                Route::get('delete_testimonials-{id}', [BusinessController::class, 'delete_testimonials']);
                Route::post('store_social_links-{id}', [BusinessController::class, 'store_social_links']);
                Route::post('store_reorder_section-{id}', [BusinessController::class, 'store_reorder_section']);
                Route::post('store_seo-{id}', [BusinessController::class, 'store_seo']);
            });
        });
        // Appointments
        Route::get('appointments', [AppointmentsController::class, 'index'])->middleware('vendor');
        Route::post('appointments/changestatus', [AppointmentsController::class, 'changestatus'])->middleware('vendor');
        // Inquiry
        Route::get('inquiry', [InquiryController::class, 'index'])->middleware('vendor');
    });
});
// Web
Route::get('/', [HomeController::class, 'landing']);
Route::get('{slug}', [HomeController::class, 'index']);
Route::post('{slug}/store_appointments-{id}', [AppointmentsController::class, 'store_appointments']);
Route::get('{slug}/savecard', [HomeController::class, 'savecard']);
Route::post('{slug}/store_inquiry-{id}', [InquiryController::class, 'store']);
Route::post('contact-form', function(Request $request) {
    $request->validate([
        'name' => 'required|string|min:6|max:32',
        'email' => 'required|email:rfc,dns',
        'phone' => 'required|numeric',
        'message' => 'required|string|min:8|max:500',
    ],
    [
        'name.required' => 'Ad & Soyad zorunlu alandır.',
        'email.required' => 'Eposta zorunlu alandır.',
        'phone.required' => 'Telefon zorunlu alandır.',
        'message.required' => 'Mesaj zorunlu alandır.',
        
        'name.min' => 'Ad & Soyad minimum 6 maksimum 32 karakter olmalıdır.',
        'phone.min' => 'Telefon minimum 10 maksimum 17 haneli olmalıdır.',
        'message.min' => 'Mesaj minimum 8 maksimum 500 karakter olmalıdır.',

        'name.max' => 'Ad & Soyad minimum 6 maksimum 32 karakter olmalıdır.',
        'phone.max' => 'Telefon minimum 10 maksimum 17 haneli olmalıdır.',
        'message.max' => 'Mesaj minimum 8 maksimum 500 karakter olmalıdır.',

        'name.string' => 'Ad & Soyad sadece harflerden oluşmalıdır.',
        'email.email' => 'Geçerli bir eposta adresi girmediniz.',
        'phone.numeric' => 'Telefon numarası sadece rakamlardan oluşmalıdır.',
        'message.string' => 'Mesajınız sadece harflerden oluşmalıdır.',
    ]);

    $data = [
        "name" => $request->name,
        "email" => $request->email,
        "phone" => $request->phone,
        "msg" => $request->message,
        "ip" => $request->ip(),
    ];    

    $sendmail = Mail::send('email.contactform', $data, function ($message) {
        $message->from(env('MAIL_USERNAME'))->subject('İletişim Formu');
        $message->to('info@reisycard.com');
    });

    return redirect()->to(url()->previous().'#contact')->with('success', 'Başarıyla gönderildi. En kısa sürede tarafınızla iletişime geçilecektir.');
})->name('contact-form');
Route::post('add-to-addressbook', function(Request $request) {
    
    $request->validate([
        'number' => 'required',
        'email' => 'required',
        'name' => 'required',
        'url' => 'nullable',
    ]);
    
    $n = explode(' ', $request->name);
    
    header("Content-type: text/x-vcard; charset=utf-8");
    header("Content-Disposition: attachment; filename=\"$request->name.vcf\";");
    
    echo "BEGIN:VCARD\n";
    echo "VERSION:3.0\n";
    echo "N:{{$n[1]}};{{$n[0]}}\n";
    echo "FN:$request->name\n";
    echo "ADR:;;;;;;\n";
    echo "TEL;WORK;VOICE:\n";
    echo "TEL;CELL:$request->number\n";
    echo "TEL;FAX:\n";
    echo "EMAIL;WORK;INTERNET:$request->email\n";
    echo "URL:$request->url\n";
    echo "END:VCARD\n";
})->name('add-to-addressbook');